Struct UntrackedWriteGuard
pub struct UntrackedWriteGuard<T>(ArcRwLockWriteGuardian<T>)
where
T: 'static;Expand description
A guard that provides mutable access to a signal’s inner value, but does not notify of any changes.
Tuple Fields
0: ArcRwLockWriteGuardian<T>Implementations
impl<T> UntrackedWriteGuard<T>where
T: 'static,
impl<T> UntrackedWriteGuard<T>where
T: 'static,
pub fn try_new(inner: Arc<RwLock<T>>) -> Option<UntrackedWriteGuard<T>>
pub fn try_new(inner: Arc<RwLock<T>>) -> Option<UntrackedWriteGuard<T>>
Creates a write guard from the given lock.